@@ -6,10 +6,10 @@ require SQL::Statement::Placeholder;
 require SQL::Statement::Function;
 
 use Data::Dumper;
-use Params::Util qw(_HASH _ARRAY0);
+use Params::Util qw(_HASH _ARRAY0 _INSTANCE);
 use Scalar::Util qw(blessed weaken);
 
-our $VERSION = '1.21_5';
+our $VERSION = '1.27_01';
 
 my %oplist = (
                '='       => 'Equal',
@@ -30,15 +30,29 @@ my %oplist = (
 
 sub new
 {
-    my $class = shift;
-    my $owner = shift;
-    my $self  = bless( { OWNER => $owner, }, $class );
+    my ( $class, $owner ) = @_;
+    my $self = bless( { OWNER => $owner, }, $class );
 
     weaken( $self->{OWNER} );
 
     return $self;
 }
 
+my %opClasses;
+
+sub _getOpClass($)
+{
+    my ( $self, $op ) = @_;
+    unless ( defined( $opClasses{$op} ) )
+    {
+        my $opBase = 'SQL::Statement::Operation';
+        my $opDialect = join( '::', $opBase, $self->{OWNER}->{dialect}, $oplist{$op} );
+        $opClasses{$op} = UNIVERSAL::isa( $opDialect, $opBase ) ? $opDialect : join( '::', $opBase, $oplist{$op} );
+    }
+
+    return $opClasses{$op};
+}
+
 sub buildCondition
 {
     my ( $self, $pred ) = @_;
@@ -57,7 +71,7 @@ sub buildCondition
         }
         elsif ( defined( $oplist{$op} ) )
         {
-            my $cn    = 'SQL::Statement::Operation::' . $oplist{$op};
+            my $cn    = $self->_getOpClass($op);
             my $left  = $self->buildCondition( $pred->{arg1} );
             my $right = $self->buildCondition( $pred->{arg2} );
             $term = $cn->new( $self->{OWNER}, $op, $left, $right );
@@ -67,9 +81,10 @@ sub buildCondition
             my $left  = $self->buildCondition( $pred->{arg1} );
             my $right = $self->buildCondition( $pred->{arg2} );
 
-            $term = SQL::Statement::Function::UserFunc->new( $self->{OWNER}, $op,
-                                                             $self->{OWNER}->{opts}->{function_names}->{$op},
-                                                             [ $left, $right ] );
+            $term =
+              SQL::Statement::Function::UserFunc->new( $self->{OWNER}, $op,
+                                                       $self->{OWNER}->{opts}->{function_names}->{$op},
+                                                       [ $left, $right ] );
         }
         else
         {
@@ -134,6 +149,10 @@ sub buildCondition
             return $self->{OWNER}->do_err( sprintf( q{Unknown type '%s'}, $pred->{type} ) );
         }
     }
+    elsif ( defined( _INSTANCE( $pred, 'SQL::Statement::Term' ) ) )
+    {
+        return $pred;
+    }
     else
     {
         return $self->{OWNER}->do_err( sprintf( q~Unknown predicate '{%s}'~, Dumper($pred) ) );
@@ -170,10 +189,17 @@ The concept of a factory can be studied in I<Design Patterns> by the Gang of
 Four. The concept of using polymophism instead of conditions is suggested by
 Martin Fowler in his book I<Refactoring>.
 
+=head1 METHODS
+
+=head2 buildCondition
+
+Builds a condition object from a given (part of a) where clause. This method
+calls itself recursively for I<predicates>.
+
 =head1 AUTHOR AND COPYRIGHT
 
 Copyright (c) 2001,2005 by Jeff Zucker: jzuckerATcpan.org
-Copyright (c) 2008,2009 by Jens Rehsack: rehsackATcpan.org
+Copyright (c) 2008-2010 by Jens Rehsack: rehsackATcpan.org
 
 Portions Copyright (C) 1998 by Jochen Wiedmann: jwiedATcpan.org
 
